@@ -7,6 +7,8 @@ OC.L10N.register(
     "Work" : "Trabayu",
     "Personal" : "Personal",
     "Mail" : "Corréu electrónicu",
+    "Save" : "Guardar",
+    "There was an error while setting up your account" : "Hebo un error mentanto se configuraba la cuenta",
     "Name" : "Nome",
     "Password" : "Contraseña",
     "Manual" : "Manual",
@@ -25,14 +27,11 @@ OC.L10N.register(
     "SMTP Port" : "Puertu de SMTP",
     "SMTP User" : "Usuariu de SMTP",
     "SMTP Password" : "Contraseña de SMTP",
-    "Save" : "Guardar",
-    "There was an error while setting up your account" : "Hebo un error mentanto se configuraba la cuenta",
     "Aliases" : "Nomatos",
     "Signature" : "Firma",
     "Default folders" : "Carpetes predeterminaes",
     "Automatic trash deletion" : "Desaniciu automáticu de la papelera",
     "Autoresponder" : "Rempuesta automática",
-    "Please connect to a sieve server first." : "Conéctate a un sirvidor sieve primero.",
     "Filters" : "Filtros",
     "Mail server" : "Sirvidor de corréu electrónicu",
     "Go back" : "Dir p'atrás",
@@ -48,6 +47,7 @@ OC.L10N.register(
     "Gravatar settings" : "Configuración de Gravatar",
     "Register" : "Rexistrase",
     "S/MIME" : "S/MIME",
+    "About" : "Tocante a",
     "Keyboard shortcuts" : "Atayos del tecláu",
     "Archive" : "Archivar",
     "Delete" : "Desaniciar",
@@ -56,6 +56,10 @@ OC.L10N.register(
     "Refresh" : "Anovar",
     "Certificate updated" : "Anovóse'l certificáu",
     "Could not update certificate" : "Nun se pudo anovar el certificáu",
+    "Send later" : "Unviar dempués",
+    "Turn off formatting" : "Desactivar el formatu",
+    "Turn off and remove formatting" : "Desactivar y quitar el formatu",
+    "Keep formatting" : "Caltener el formatu",
     "From" : "De",
     "To" : "Pa",
     "Cc" : "Cc",
@@ -67,25 +71,26 @@ OC.L10N.register(
     "Enable formatting" : "Activar el formatu",
     "Disable formatting" : "Desactivar el formatu",
     "Smart picker" : "Selector intelixente",
-    "Send later" : "Unviar dempués",
     "Send now" : "Unviar agora",
     "Tomorrow morning" : "Mañana pela mañana",
     "Tomorrow afternoon" : "Mañana pela tarde",
     "Monday morning" : "Llunes pela mañana",
     "Enter a date" : "Introduz una data",
-    "Turn off formatting" : "Desactivar el formatu",
-    "Turn off and remove formatting" : "Desactivar y quitar el formatu",
-    "Keep formatting" : "Caltener el formatu",
     "Choose" : "Escoyer",
+    "Untitled message" : "Mensaxe ensin títulu",
     "Expand composer" : "Espander el compositor",
     "Close composer" : "Zarrar el compositor",
-    "Untitled message" : "Mensaxe ensin títulu",
     "Confirm" : "Confirmar",
     "An error occurred, unable to delete the tag." : "Prodúxose un error, nun ye posible desaniciar la etiqueta.",
     "Plain text" : "Testu ensin formatu",
     "Rich text" : "Testu arriquecíu",
     "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
     "No messages" : "Nun hai nengún mensaxe",
+    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
+    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
+    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
+    "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
+    "Could not archive message" : "Nun se pudo archivar el mensaxe",
     "Draft: " : "Borrador:",
     "Encrypted message" : "Mensaxe cifráu",
     "This message is unread" : "Esta mensaxe ta ensin lleer",
@@ -101,15 +106,19 @@ OC.L10N.register(
     "Create event" : "Crear un eventu",
     "Create task" : "Crear la xera",
     "Download message" : "Baxar el mensaxe",
-    "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
-    "Could not archive message" : "Nun se pudo archivar el mensaxe",
     "Load more" : "Cargar más",
     "Report this bug" : "Informar d'esti fallu",
+    "Event created" : "Creóse l'eventu",
+    "Could not create event" : "Nun se pudo crear l'eventu",
     "All day" : "Tol día",
     "Description" : "Descripción",
     "Create" : "Crear",
-    "Event created" : "Creóse l'eventu",
-    "Could not create event" : "Nun se pudo crear l'eventu",
+    "This event was updated" : "Esti eventu anovóse",
+    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó la to invitación",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó provisionalmente la to invitación",
+    "{attendeeName} declined your invitation" : "{attendeeName} refugó la to invitación",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reaicionó a la to invitación",
+    "Failed to save your participation status" : "Nun se pudo guardar l'estáu de la to participación",
     "You accepted this invitation" : "Aceptesti esta invitación",
     "You tentatively accepted this invitation" : "Aceptesti esta invitación provisionalmente",
     "You declined this invitation" : "Refuguesti esta invitación",
@@ -123,61 +132,50 @@ OC.L10N.register(
     "Tentatively accept" : "Aceptar provisionalmente",
     "More options" : "Más opciones",
     "This event is in the past." : "Esti eventu ye del pasáu.",
-    "This event was updated" : "Esti eventu anovóse",
-    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó la to invitación",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó provisionalmente la to invitación",
-    "{attendeeName} declined your invitation" : "{attendeeName} refugó la to invitación",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} reaicionó a la to invitación",
-    "Failed to save your participation status" : "Nun se pudo guardar l'estáu de la to participación",
+    "individual" : "individual",
     "domain" : "dominiu",
     "Remove" : "Quitar",
-    "individual" : "individual",
     "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
     "Loading messages …" : "Cargando los mensaxes…",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
     "Important info" : "Información importante",
     "Forward" : "Avanzar",
     "Move message" : "Mover el mensaxe",
+    "Translate" : "Traducir",
     "View source" : "Ver l'orixe",
     "Message body" : "Cuerpu del mensaxe",
-    "Save to Files" : "Guardar en Ficheros",
     "Unnamed" : "Ensin nome",
     "Embedded message" : "Mensaxe empotráu",
+    "Save to Files" : "Guardar en Ficheros",
     "Save all to Files" : "Guardar too en Ficheros",
     "The images have been blocked to protect your privacy." : "Bloquiáronse les imáxenes pa protexer la to privacidá.",
     "Show images" : "Amosar les imáxenes",
     "Show images temporarily" : "Amosar les imáxenes temporalmente",
     "Quoted text" : "Cita",
     "Move" : "Mover",
+    "Loading …" : "Cargando…",
+    "Not supported by the server" : "Nun ye compatible col sirvidor",
+    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
+    "Remove account" : "Quitar la cuenta",
+    "Remove {email}" : "Quitar {email}",
     "Quota" : "Cuota",
     "Add mailbox" : "Amestar una bandexa",
     "Mailbox name" : "Nome de la bandexa",
     "Saving" : "Guardando",
     "Move up" : "Xubir",
     "Move down" : "Baxar",
-    "Remove account" : "Quitar la cuenta",
-    "Loading …" : "Cargando…",
-    "Not supported by the server" : "Nun ye compatible col sirvidor",
-    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
-    "Remove {email}" : "Quitar {email}",
     "Show all mailboxes" : "Amosar toles bandexes",
     "Collapse mailboxes" : "Contrayer toles bandexes",
-    "Rename" : "Renomar",
-    "Move mailbox" : "Mover la bandexa",
-    "Delete mailbox" : "Desaniciar la bandexa",
+    "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
     "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
     "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
+    "Delete mailbox" : "Desaniciar la bandexa",
     "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
     "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
-    "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
+    "Rename" : "Renomar",
+    "Move mailbox" : "Mover la bandexa",
     "Outbox" : "Bandexa de salida",
     "New message" : "Mensaxe nuevu",
-    "Error sending your message" : "Hebo un error al unviar el mensaxe",
-    "Retry" : "Retentar",
-    "Sending …" : "Unviando…",
-    "Send anyway" : "Unviar de toes toes",
-    "Maximize composer" : "Maximizar el compositor",
-    "Minimize composer" : "Minimizar el compositor",
     "Edit message" : "Editar el mensaxe",
     "Draft" : "Borrador",
     "Reply" : "Responder",
@@ -186,17 +184,25 @@ OC.L10N.register(
     "Failed to save draft" : "Nun se pue guardar el borrador",
     "Message discarded" : "Escartóse'l mensaxe",
     "Could not discard message" : "Nun se pudo escartar el mensaxe",
-    "Welcome to {cloudName} Mail" : "Afáyate en {cloudName} Mail",
+    "Maximize composer" : "Maximizar el compositor",
+    "Minimize composer" : "Minimizar el compositor",
+    "Error sending your message" : "Hebo un error al unviar el mensaxe",
+    "Retry" : "Retentar",
+    "Sending …" : "Unviando…",
+    "Send anyway" : "Unviar de toes toes",
     "First day" : "El primer día",
     "Message" : "Mensaxe",
     "Oh Snap!" : "¡Meca!",
     "Message deleted" : "Desnaicióse'l mensaxe",
+    "Copied email address to clipboard" : "La direición de corréu electrónicu copióse nel cartafueyu",
+    "Could not copy email address to clipboard" : "Nun se pudo copiar la direición de corréu electrónicu nel cartafueyu",
     "Contacts with this address" : "Contautos con esta direición",
     "New Contact" : "Contautu nuevu",
     "Copy to clipboard" : "Copiar nel cartafueyu",
     "Add" : "Amestar",
-    "Copied email address to clipboard" : "La direición de corréu electrónicu copióse nel cartafueyu",
-    "Could not copy email address to clipboard" : "Nun se pudo copiar la direición de corréu electrónicu nel cartafueyu",
+    "Show less" : "Amosar menos",
+    "Show more" : "Amosar más",
+    "Clear" : "Borrar",
     "Close" : "Zarrar",
     "Search parameters" : "Parámetros de busca",
     "Body" : "Cuerpu",
@@ -207,34 +213,39 @@ OC.L10N.register(
     "Tags" : "Etiquetes",
     "Select tags" : "Seleicionar etiquetes",
     "Last 7 days" : "Los últimos 7 díes",
-    "Clear" : "Borrar",
     "Sieve Port" : "Puertu de sieve",
     "Custom" : "Personalizar",
     "Sieve User" : "Usuariu de sieve",
     "Sieve Password" : "Contraseña de sieve",
     "Save sieve settings" : "Guardar la configuración de sieve",
-    "Save sieve script" : "Guardar el script de sieve",
     "The syntax seems to be incorrect:" : "La sintaxis paez ser incorreuta",
+    "Save sieve script" : "Guardar el script de sieve",
+    "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Delete tag" : "Desaniciar la etiqueta",
     "Set tag" : "Afitar la etiqueta",
     "Unset tag" : "Quitar la etiqueta",
-    "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
-    "Add tag" : "Amestar la etiqueta",
-    "Saving tag …" : "Guardando la etiqueta…",
     "Tag already exists" : "La etiqueta yá esiste",
     "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
     "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
+    "Add tag" : "Amestar la etiqueta",
+    "Saving tag …" : "Guardando la etiqueta…",
     "Task created" : "Creóse la xera",
     "Could not create task" : "Nun se pudo crear la xera",
-    "Loading thread" : "Cargando'l filu",
-    "Not found" : "Nun s'atopó",
     "Summarizing thread failed." : "El resume del filu falló.",
     "Could not load your message thread" : "Nun se pudo cargar el filu de mensaxes",
+    "Loading thread" : "Cargando'l filu",
+    "Not found" : "Nun s'atopó",
     "Archive message" : "Archivar el mensaxe",
     "Delete message" : "Desaniciar el mensaxe",
     "Message source" : "Orixe del mensaxe",
     "Go to latest message" : "Dir al últimu mensaxe",
     "Go to newest message" : "Dir al mensaxe más nuevu",
+    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
+    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
+    "Translation could not be copied" : "Nun se pudo copiar la traducción",
+    "Translate message" : "Traducir el mensaxe",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar el testu traducíu",
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
@@ -243,9 +254,9 @@ OC.L10N.register(
     "Filter name" : "Nome de la peñera",
     "Actions" : "Aiciones",
     "Priority" : "Prioridá",
+    "Error saving config" : "Hebo un error al guardar la configuración",
     "Anti Spam Service" : "Serviciu de antispam",
     "Gmail integration" : "Integración con Gmail",
-    "Error saving config" : "Hebo un error al guardar la configuración",
     "Anti Spam" : "Antispam",
     "Reset" : "Reafitar",
     "Client ID" : "ID de veceru",
@@ -259,6 +270,10 @@ OC.L10N.register(
     "Use master password" : "Usar la contraseña maestra",
     "Sieve" : "Sieve",
     "Save Config" : "Guardar la configuración",
+    "Failed to import the certificate. Please check the password." : "Nun se pue importar el certificáu. Comprueba la contraseña.",
+    "Certificate imported successfully" : "El certificáu importóse correutamente",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nun se pue importar el certificáu. Asegúrate de que la clave privada concasa cola del certificáu y nun ta protexida con una clave d'accesu.",
+    "Failed to import the certificate" : "Nun se pue importar el certificáu",
     "S/MIME certificates" : "Certificaos S/MIME",
     "Certificate name" : "Nome del certificáu",
     "E-mail address" : "Direición de corréu electrónicu",
@@ -269,15 +284,8 @@ OC.L10N.register(
     "Certificate" : "Certificáu",
     "Private key (optional)" : "Clave privada (opcional)",
     "Submit" : "Unviar",
-    "Failed to import the certificate. Please check the password." : "Nun se pue importar el certificáu. Comprueba la contraseña.",
-    "Certificate imported successfully" : "El certificáu importóse correutamente",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nun se pue importar el certificáu. Asegúrate de que la clave privada concasa cola del certificáu y nun ta protexida con una clave d'accesu.",
-    "Failed to import the certificate" : "Nun se pue importar el certificáu",
     "Account connected" : "Conectóse la cuenta",
     "You can close this window" : "Pues zarrar esta ventana",
-    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
-    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "All" : "Too",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
