@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "პირადი",
     "Later" : "მოგვიანებით",
     "Mail" : "ფოსტა",
+    "Connecting" : "მყარდება კავშირი",
+    "Save" : "შენახვა",
+    "Connect" : "დაკავშირება",
+    "Password required" : "საჭიროა პაროლი",
     "Name" : "სახელი",
     "Mail address" : "ფოსტის მისამართი",
     "Password" : "პაროლი",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP პორტი",
     "SMTP User" : "SMTP მომხმარებელი",
     "SMTP Password" : "SMTP პაროლი",
-    "Connecting" : "მყარდება კავშირი",
-    "Save" : "შენახვა",
-    "Connect" : "დაკავშირება",
-    "Password required" : "საჭიროა პაროლი",
     "Aliases" : "სხვანაირი სახელი",
     "Signature" : "ხელმოწერა",
     "Go back" : "უკან დაბრუნება",
@@ -33,6 +33,7 @@ OC.L10N.register(
     "General" : "ზოგადი",
     "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
     "Register" : "რეგისტრაცია",
+    "About" : "ჩვენს შესახებ",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
@@ -48,8 +49,8 @@ OC.L10N.register(
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
     "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
-    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Choose" : "აირჩიეთ",
+    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Confirm" : "დადასტურება",
     "Unfavorite" : "რჩეულებიდან ამოშლა",
     "Favorite" : "რჩეული",
@@ -68,32 +69,33 @@ OC.L10N.register(
     "email" : "ელ-ფოსტა",
     "Other" : "სხვა",
     "Forward" : "წინ",
+    "Translate" : "გადათარგმნეთ",
+    "Unnamed" : "უსახელო",
     "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
     "Import into calendar" : "იმპორტი კალენდარში",
     "Download attachment" : "დანართის გადმოწერა",
     "Save to Files" : "შენახვა ფაილებში",
-    "Unnamed" : "უსახელო",
     "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
     "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
     "Move" : "გადატანა",
+    "Remove account" : "ანგარიშის გაუქმება",
     "Quota" : "კვოტა",
     "Saving" : "მიმდინარეობს შენახვა",
-    "Remove account" : "ანგარიშის გაუქმება",
     "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
     "Rename" : "სახელის შეცვლა",
     "Clear cache" : "კეშის გასუფთავება",
     "New message" : "ახალი წერილი",
+    "Reply" : "პასუხი",
     "Retry" : "ვცადოთ ახლიდან",
     "Sending …" : "იგზავნება …",
-    "Reply" : "პასუხი",
     "Message" : "წერილი",
     "Copy to clipboard" : "კოპირება ბუფერში",
     "Add" : "დამატება",
+    "Clear" : "გასუფთავება",
     "Close" : "დახურვა",
     "Date" : "თარიღი",
     "Tags" : "ტეგები",
     "Select tags" : "აირჩიეთ ტეგები",
-    "Clear" : "გასუფთავება",
     "Custom" : "ინდივიდუალური",
     "Add tag" : "ტეგის დამატება",
     "Mark as unread" : "წაუკითხავად მონიშვნა",
