@@ -17,6 +17,14 @@ OC.L10N.register(
     "Drafts are saved in:" : "Utkast sparas i:",
     "Sent messages are saved in:" : "Skickade meddelanden sparas i:",
     "Deleted messages are moved in:" : "Raderade meddelanden flyttas till:",
+    "Connecting" : "Ansluter",
+    "Save" : "Spara",
+    "Connect" : "Anslut",
+    "Password required" : "Lösenord krävs",
+    "IMAP username or password is wrong" : "IMAP-användarnamn eller lösenord är felaktigt",
+    "SMTP username or password is wrong" : "SMTP-användarnamn eller lösenord är felaktigt",
+    "IMAP connection failed" : "IMAP-anslutning misslyckades",
+    "SMTP connection failed" : "SMTP-anslutning misslyckades",
     "Auto" : "Auto",
     "Name" : "Namn",
     "Mail address" : "E-postadress",
@@ -39,14 +47,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP-port",
     "SMTP User" : "SMTP-användare",
     "SMTP Password" : "SMTP-lösenord",
-    "Connecting" : "Ansluter",
-    "Save" : "Spara",
-    "Connect" : "Anslut",
-    "Password required" : "Lösenord krävs",
-    "IMAP username or password is wrong" : "IMAP-användarnamn eller lösenord är felaktigt",
-    "SMTP username or password is wrong" : "SMTP-användarnamn eller lösenord är felaktigt",
-    "IMAP connection failed" : "IMAP-anslutning misslyckades",
-    "SMTP connection failed" : "SMTP-anslutning misslyckades",
     "Account settings" : "Kontoinställningar",
     "Aliases" : "Alias",
     "Signature" : "Signatur",
@@ -64,6 +64,9 @@ OC.L10N.register(
     "Add alias" : "Lägg till alias",
     "Create alias" : "Skapa alias",
     "Cancel" : "Avbryt",
+    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
+    "Could not update preference" : "Kunde inte uppdatera inställningar",
+    "Mail settings" : "E-postinställningar",
     "Accounts" : "Konton",
     "Add mail account" : "Lägg till e-postkonto",
     "General" : "Allmänt",
@@ -77,6 +80,7 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
     "Trusted senders" : "Betrodda avsändare",
     "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
+    "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
     "Newer message" : "Nyare meddelande",
@@ -88,8 +92,8 @@ OC.L10N.register(
     "Search" : "Sök",
     "Send" : "Skicka",
     "Refresh" : "Uppdatera",
-    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
-    "Could not update preference" : "Kunde inte uppdatera inställningar",
+    "Send later" : "Skicka senare",
+    "Message {id} could not be found" : "Meddelandet {id} hittades inte",
     "From" : "Från",
     "Select account" : "Välj konto",
     "To" : "Till",
@@ -110,7 +114,6 @@ OC.L10N.register(
     "Upload attachment" : "Ladda upp bilaga",
     "Add attachment from Files" : "Lägg till bilaga från Filer",
     "Smart picker" : "Smart picker",
-    "Send later" : "Skicka senare",
     "Request a read receipt" : "Begär läskvitto",
     "Encrypt message with Mailvelope" : " Kryptera meddelande med \"Mailvelope\"",
     "Send now" : "Skicka nu",
@@ -119,16 +122,28 @@ OC.L10N.register(
     "Monday morning" : "Måndag morgon",
     "Custom date and time" : "Anpassat datum och tid",
     "Enter a date" : "Ange datum",
-    "Message {id} could not be found" : "Meddelandet {id} hittades inte",
+    "Choose" : "Välj",
     "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
     "Choose a file to share as a link" : "Välj en fil att dela som länk",
-    "Choose" : "Välj",
     "_{count} attachment_::_{count} attachments_" : ["{count} bilaga","{count} bilagor"],
     "Confirm" : "Bekräfta",
     "Plain text" : "Oformaterad text",
     "Rich text" : "Formaterad text",
     "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
     "No messages" : "Inga meddelanden",
+    "Blind copy recipients only" : "Endast mottagare för blindkopior",
+    "No subject" : "Ingen ämnesrad",
+    "Later today – {timeLocale}" : "Senare idag – {timeLocale}",
+    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
+    "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
+    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
+    "This weekend – {timeLocale}" : "Den här helgen – {timeLocale}",
+    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
+    "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
+    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
+    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
+    "Could not delete message" : "Kunde inte radera meddelande",
+    "Could not archive message" : "Kunde inte arkivera meddelandet",
     "Draft: " : "Utkast:",
     "Unfavorite" : "Inte favorit",
     "Favorite" : "Favorit",
@@ -146,15 +161,6 @@ OC.L10N.register(
     "Edit as new message" : "Redigera som nytt meddelande",
     "Create event" : "Skapa evenemang",
     "Create task" : "Skapa uppgift",
-    "Blind copy recipients only" : "Endast mottagare för blindkopior",
-    "No subject" : "Ingen ämnesrad",
-    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
-    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
-    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
-    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
-    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
-    "Could not delete message" : "Kunde inte radera meddelande",
-    "Could not archive message" : "Kunde inte arkivera meddelandet",
     "Load more" : "Ladda mer",
     "_Mark {number} read_::_Mark {number} read_" : ["Markera {number} meddelande som läst","Markera {number} meddelanden som lästa"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Markera {number} meddelande som oläst","Markera {number} meddelanden som olästa"],
@@ -164,42 +170,43 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Flytta {number} tråd","Flytta {number} trådar"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Vidarebefordra {number} som bilaga","Vidarebefordra {number} som bilagor"],
     "Report this bug" : "Rapportera detta fel",
+    "Event created" : "Evenemang skapat",
+    "Could not create event" : "Kunde inte skapa händelse",
     "All day" : "Hela dagen",
     "Description" : "Beskrivning",
     "Create" : "Skapa",
-    "Event created" : "Evenemang skapat",
-    "Could not create event" : "Kunde inte skapa händelse",
     "Select" : "Välj",
     "Comment" : "Kommentar",
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
     "More options" : "Fler alternativ",
+    "individual" : "individ",
     "domain" : "domän",
     "Remove" : "Ta bort",
     "email" : "e-post",
-    "individual" : "individ",
     "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
     "Could not open mailbox" : "Kunde inte öppna brevlådan",
     "Loading messages …" : "Läser in meddelanden …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
     "Choose target mailbox" : "Välj markerad inkorg",
     "No more submailboxes in here" : "Inga fler undermappar här",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
     "Important info" : "Viktig info",
     "Other" : "Övrigt",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
     "Notify the sender" : "Meddela avsändaren",
     "You sent a read confirmation to the sender of this message." : "Du har skickat ett läskvitto till meddelandets avsändare.",
     "Forward" : "Vidarebefordra",
     "Move message" : "Flytta meddelande",
+    "Translate" : "Översätt",
     "Forward message as attachment" : "Vidarebefordra medelande som bilaga",
     "View source" : "Visa källa",
     "Message body" : "Meddelandetext",
+    "Unnamed" : "Namnlös",
+    "Embedded message" : "Inbäddat meddelande",
     "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
     "Import into calendar" : "Importera till kalender",
     "Download attachment" : "Hämta bilaga",
     "Save to Files" : "Spara till filer",
-    "Unnamed" : "Namnlös",
-    "Embedded message" : "Inbäddat meddelande",
     "Choose a folder to store the attachments in" : "Välj en mapp att spara bifogade filer i",
     "Save all to Files" : "Spara alla i filer",
     "Download Zip" : "Ladda ner arkiv",
@@ -215,20 +222,24 @@ OC.L10N.register(
     "Moving" : "Flyttar",
     "Moving thread" : "Flyttar tråd",
     "Moving message" : "Flyttar meddelande",
+    "Loading …" : "Läser in ...",
+    "Not supported by the server" : "Stöds ej av  servern",
+    "{usage} of {limit} used" : "{usage} av {limit} använt",
+    "Remove account" : "Ta bort konto",
+    "Remove {email}" : "Ta bort {email}",
     "Quota" : "Kvot",
     "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
     "Add mailbox" : "Lägg till brevlåda",
     "Saving" : "Sparar",
     "Move up" : "Flytta upp",
     "Move down" : "Flytta ner",
-    "Remove account" : "Ta bort konto",
-    "Loading …" : "Läser in ...",
-    "Not supported by the server" : "Stöds ej av  servern",
-    "{usage} of {limit} used" : "{usage} av {limit} använt",
-    "Remove {email}" : "Ta bort {email}",
     "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
     "Show all mailboxes" : "Visa alla brevlådor",
     "Collapse mailboxes" : "Minimera brevlådor",
+    "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
+    "Delete mailbox" : "Radera brevlåda",
+    "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
     "Mark all as read" : "Markera alla som lästa",
     "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
     "Rename" : "Byt namn",
@@ -236,20 +247,16 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Rensa lokalt cachad data, ifall det finns problem med synkronisering.",
     "Subscribed" : "Prenumeration aktiverad",
     "Sync in background" : "Synkronisera i bakgrunden",
-    "Delete mailbox" : "Radera brevlåda",
-    "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
-    "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
     "Outbox" : "Utkorg",
     "New message" : "Nytt meddelande",
+    "Edit message" : "Redigera meddelande",
+    "Draft" : "Utkast",
+    "Reply" : "Svara",
     "Error sending your message" : "Ett fel inträffade när ditt meddelande skulle skickas",
     "Retry" : "Försök igen",
     "Uploading attachments …" : "Laddar upp bilagor ...",
     "Sending …" : "Skickar ...",
     "Send anyway" : "Skicka ändå",
-    "Edit message" : "Redigera meddelande",
-    "Draft" : "Utkast",
-    "Reply" : "Svara",
-    "Welcome to {cloudName} Mail" : "Välkommen till {cloudName} Mail",
     "First day" : "Första dagen",
     "Message" : "Meddelande",
     "Oh Snap!" : "Hoppsan!",
@@ -260,6 +267,9 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiera till urklipp",
     "Contact name …" : "Kontaktnamn …",
     "Add" : "Lägg till",
+    "Show less" : "Visa mindre",
+    "Show more" : "Visa mer",
+    "Clear" : "Rensa",
     "Search in mailbox" : "Sök i brevlådan",
     "Close" : "Stäng",
     "Search parameters" : "Sökparametrar",
@@ -270,39 +280,48 @@ OC.L10N.register(
     "Tags" : "Taggar",
     "Select tags" : "Välj taggar",
     "Last 7 days" : "Senaste 7 dagarna",
-    "Clear" : "Rensa",
     "Custom" : "Anpassad",
     "Signature …" : "Signatur …",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
-    "Delete tag" : "Radera tagg",
     "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
+    "Delete tag" : "Radera tagg",
+    "Tag already exists" : "Taggen finns redan",
+    "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
     "Add default tags" : "Lägg till standardtaggar",
     "Add tag" : "Lägg till tagg",
     "Saving tag …" : "Sparar tagg …",
-    "Tag already exists" : "Taggen finns redan",
-    "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
-    "Not found" : "Hittades inte",
     "Could not load your message thread" : "Det gick inte att ladda meddelandetråden",
-    "Unsubscribe" : "Avsluta prenumeration",
+    "Not found" : "Hittades inte",
     "Reply all" : "Svara alla",
+    "Unsubscribe" : "Avsluta prenumeration",
     "Reply to sender only" : "Svara endast avsändaren",
     "Mark as unread" : "Markera som oläst",
     "Mark as read" : "Markera som läst",
     "Archive message" : "Arkivera meddelandet",
     "Delete message" : "Radera meddelande",
     "Message source" : "Meddelandekälla",
+    "The message could not be translated" : "Meddelandet kunde inte översättas",
+    "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
+    "Translation could not be copied" : "Översättningen kunde inte kopieras",
+    "Translate message" : "Översätt meddelande",
+    "Source language to translate from" : "Språk att översätta från",
+    "Translate from" : "Översätt från",
+    "Target language to translate into" : "Språk att översätta till",
+    "Translate to" : "Översätt till",
+    "Translating" : "Översätter",
+    "Copy translated text" : "Kopiera översatt text",
     "No senders are trusted at the moment." : "Inga avsändare är betrodda för tillfället.",
-    "(organizer)" : "(arrangör)",
     "Untitled event" : "Namnlös händelse",
+    "(organizer)" : "(arrangör)",
     "Import into {calendar}" : "Importera till {calendar}",
     "Event imported into {calendar}" : "Händelse importerad till {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flyg {flightNr} från {depAirport} till {arrAirport}",
     "Airplane" : "Flygplan",
     "Reservation {id}" : "Bokning {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flyg {flightNr} från {depAirport} till {arrAirport}",
-    "Train" : "Tåg",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
+    "Train" : "Tåg",
     "Delete filter" : "Ta bort filter",
     "Operator" : "Operatör",
     "Filter name" : "Filternamn",
@@ -332,10 +351,6 @@ OC.L10N.register(
     "Submit" : "Skicka",
     "Account connected" : "Konto anslutet",
     "Connect your mail account" : "Anslut ditt e-postkonto",
-    "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
-    "This weekend – {timeLocale}" : "Den här helgen – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
-    "Later today – {timeLocale}" : "Senare idag – {timeLocale}",
     "All" : "Alla",
     "Drafts" : "Utkast",
     "Favorites" : "Favoriter",
@@ -362,7 +377,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s",
-    "Unselect" : "Avmarkera"
+    "Continue to %s" : "Fortsätt till %s"
 },
 "nplurals=2; plural=(n != 1);");
