@@ -2,25 +2,9 @@
 
 declare(strict_types=1);
 
-/*
- * @copyright 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @author 2020 Christoph Wurst <christoph@winzerhof-wurst.at>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+/**
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Listener;
@@ -40,6 +24,9 @@ use function in_array;
 use function json_decode;
 use function strtolower;
 
+/**
+ * @template-implements IEventListener<Event|MailboxesSynchronizedEvent>
+ */
 class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 	/** @var MailAccountMapper */
 	private $mailAccountMapper;
@@ -51,8 +38,8 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 	private $logger;
 
 	public function __construct(MailAccountMapper $mailAccountMapper,
-								MailboxMapper $mailboxMapper,
-								LoggerInterface $logger) {
+		MailboxMapper $mailboxMapper,
+		LoggerInterface $logger) {
 		$this->mailAccountMapper = $mailAccountMapper;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->logger = $logger;
@@ -74,7 +61,7 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 				$draftsMailbox = $this->findSpecial($mailboxes, 'drafts');
 				$mailAccount->setDraftsMailboxId($draftsMailbox->getId());
 			} catch (DoesNotExistException $e) {
-				$this->logger->info("Account " . $account->getId() . " does not have a drafts mailbox");
+				$this->logger->info('Account ' . $account->getId() . ' does not have a drafts mailbox');
 
 				$mailAccount->setDraftsMailboxId(null);
 			}
@@ -84,7 +71,7 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 				$sentMailbox = $this->findSpecial($mailboxes, 'sent');
 				$mailAccount->setSentMailboxId($sentMailbox->getId());
 			} catch (DoesNotExistException $e) {
-				$this->logger->info("Account " . $account->getId() . " does not have a sent mailbox");
+				$this->logger->info('Account ' . $account->getId() . ' does not have a sent mailbox');
 
 				$mailAccount->setSentMailboxId(null);
 			}
@@ -94,7 +81,7 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 				$trashMailbox = $this->findSpecial($mailboxes, 'trash');
 				$mailAccount->setTrashMailboxId($trashMailbox->getId());
 			} catch (DoesNotExistException $e) {
-				$this->logger->info("Account " . $account->getId() . " does not have a trash mailbox");
+				$this->logger->info('Account ' . $account->getId() . ' does not have a trash mailbox');
 
 				$mailAccount->setTrashMailboxId(null);
 			}
@@ -104,18 +91,37 @@ class MailboxesSynchronizedSpecialMailboxesUpdater implements IEventListener {
 				$archiveMailbox = $this->findSpecial($mailboxes, 'archive');
 				$mailAccount->setArchiveMailboxId($archiveMailbox->getId());
 			} catch (DoesNotExistException $e) {
-				$this->logger->info("Account " . $account->getId() . " does not have an archive mailbox");
+				$this->logger->info('Account ' . $account->getId() . ' does not have an archive mailbox');
 
 				$mailAccount->setArchiveMailboxId(null);
 			}
 		}
+		if ($mailAccount->getJunkMailboxId() === null || !array_key_exists($mailAccount->getJunkMailboxId(), $mailboxes)) {
+			try {
+				$junkMailbox = $this->findSpecial($mailboxes, 'junk');
+				$mailAccount->setJunkMailboxId($junkMailbox->getId());
+			} catch (DoesNotExistException) {
+				$this->logger->info('Account ' . $account->getId() . ' does not have an junk mailbox');
+				$mailAccount->setJunkMailboxId(null);
+			}
+		}
+		if ($mailAccount->getSnoozeMailboxId() === null || !array_key_exists($mailAccount->getSnoozeMailboxId(), $mailboxes)) {
+			try {
+				$snoozeMailbox = $this->findSpecial($mailboxes, 'snooze');
+				$mailAccount->setSnoozeMailboxId($snoozeMailbox->getId());
+			} catch (DoesNotExistException $e) {
+				$this->logger->info('Account ' . $account->getId() . ' does not have an snooze mailbox');
+
+				$mailAccount->setSnoozeMailboxId(null);
+			}
+		}
 
 		$this->mailAccountMapper->update($mailAccount);
 	}
 
 	private function indexMailboxes(array $mailboxes): array {
 		return array_combine(
-			array_map(function (Mailbox $mb): int {
+			array_map(static function (Mailbox $mb) : int {
 				return $mb->getId();
 			}, $mailboxes),
 			$mailboxes
